@@ -167,6 +167,12 @@ namespace msXpSlibmass
 	bool
 		DataPoint::initialize(const QString &xyLine)
 		{
+			//qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
+
+			// Initialize to NaN to start with.
+			m_key = qSNaN();
+			m_val = qSNaN();
+
 			QRegularExpressionMatch regExpMatch;
 
 			regExpMatch = msXpS::gXyFormatMassDataRegExp.match(xyLine);
