@@ -49,7 +49,7 @@
 /////////////////////// Local includes
 
 // For the install directory defines
-#include <config.h>
+#include "../config.h"
 
 #include <massxpert/gui/MainWindow.hpp>
 
@@ -270,9 +270,9 @@ MainWindow::initializeSystemConfig()
 // For example on MS-Windows, the following variables are defined:
 
 /*
- * #define MSXPERTSUITE_BIN_DIR C:/Program Files/msxpertsuite
- * #define MSXPERTSUITE_DATA_DIR C:/Program Files/msxpertsuite/data
- * #define MSXPERTSUITE_DOC_DIR C:/Program Files/msxpertsuite/doc/
+ * #define MASSXPERT_BIN_DIR C:/Program Files/msXpertSuite
+ * #define MASSXPERT_DATA_DIR C:/Program Files/msxpertsuite/data/massxpert
+ * #define MASSXPERT_DOC_DIR C:/Program Files/msxpertsuite/doc/massxpert
  *
  * This means that for the massxpert module, the data will be copied as
  * C:/Program Files/msxpertsuite/data/massxpert, with the data immediately
@@ -282,9 +282,9 @@ MainWindow::initializeSystemConfig()
 // On GNU/Linux, instead, the following variables are defined:
 
 /*
- * #define MSXPERTSUITE_BIN_DIR /usr/local/bin
- * #define MSXPERTSUITE_DATA_DIR /usr/local/share/msxpertsuite
- * #define MSXPERTSUITE_DOC_DIR: /usr/local/share/doc/msxpertsuite/
+ * #define MASSXPERT_BIN_DIR /usr/local/bin
+ * #define MASSXPERT_DATA_DIR /usr/local/share/msxpertsuite-massxpert/data
+ * #define MASSXPERT_DOC_DIR: /usr/local/share/doc/msxpertsuite-massxpert/doc
  *
  * This means that for the massxpert module, the data will be copied as
  * /usr/local/share/msxpertsuite/massxpert with the data immediately in
@@ -351,9 +351,9 @@ MainWindow::initializeSystemConfig()
   int errorCount = 0;
 
 
-  /////////////////// MSXPERTSUITE_DATA_DIR ///////////////////
-  /////////////////// MSXPERTSUITE_DATA_DIR ///////////////////
-  /////////////////// MSXPERTSUITE_DATA_DIR ///////////////////
+  /////////////////// MASSXPERT_DATA_DIR ///////////////////
+  /////////////////// MASSXPERT_DATA_DIR ///////////////////
+  /////////////////// MASSXPERT_DATA_DIR ///////////////////
 
   QSettings settings(m_configSettingsFilePath, QSettings::IniFormat);
   settings.beginGroup("systemDataConfigSettings");
@@ -364,7 +364,7 @@ MainWindow::initializeSystemConfig()
 
   testDir.setPath(settings.value("dataDir").toString());
 
-  if(testDir.exists())
+  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
     {
       // Ah ah, the user already configured a new directory. Fine, let's go
       // with it.
@@ -378,7 +378,7 @@ MainWindow::initializeSystemConfig()
           // located. Then, we'll craft the directory by appending
           // "Contents/Resources/data".
 
-          testDir.setPath(QString("%1/../Resources/data")
+          testDir.setPath(QString("%1/../Resources/massxpert/data")
                             .arg(QCoreApplication::applicationDirPath()));
 
           // QMessageBox::information(this,
@@ -389,18 +389,17 @@ MainWindow::initializeSystemConfig()
         {
           /////// From the config.h file
 
-
-          // On UNIX, that would be /usr/local/share/msxpertsuite/<modulename>
-          // that is, /usr/local/share/msxpertsuite/massxpert, for example.
-          testDir.setPath(QString("%1").arg(MSXPERTSUITE_DATA_DIR));
+          // On UNIX, that would be
+          // /usr/local/share/msxpertsuite-<modulename>/data
+          // that is, /usr/local/share/msxpertsuite-massxpert/data, for example.
+          testDir.setPath(QString("%1").arg(MASSXPERT_DATA_DIR));
+          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+                   //<< "From the config.h file:" << testDir.absolutePath();
         }
 
-      // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-      //<< "dir: " << QString("%1").arg(MSXPERTSUITE_DATA_DIR);
-
       // The path must be absolute and must exist.
 
-      if(testDir.exists() && testDir.isAbsolute())
+  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
         {
           // Fantastic, the initial installation directory exists and that is
           // fine.
@@ -420,9 +419,8 @@ MainWindow::initializeSystemConfig()
         }
     }
 
-  // QMessageBox::information(this,
-  //"data dir path",
-  // finalDir.absolutePath(), QMessageBox::Ok);
+  //QMessageBox::information(
+    //this, "dataDir path", finalDir.absolutePath(), QMessageBox::Ok);
 
   // QMessageBox::information(this,
   //"module",
@@ -447,11 +445,13 @@ MainWindow::initializeSystemConfig()
 
   testDir.setPath(settings.value("polChemDefsDir").toString());
 
-  if(testDir.exists())
+  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
     {
       // Ah ah, the user already configured a new directory. Fine, let's go
       // with it.
       finalDir = testDir;
+      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+               //<< "From the configSettings file:" << testDir.absolutePath();
     }
   else
     {
@@ -461,7 +461,7 @@ MainWindow::initializeSystemConfig()
           // located. Then, we'll craft the directory by appending
           // "Contents/Resources/data".
 
-          testDir.setPath(QString("%1/../Resources/data/polChemDefs")
+          testDir.setPath(QString("%1/../Resources/massxpert/data/polChemDefs")
                             .arg(QCoreApplication::applicationDirPath()));
 
           // QMessageBox::information(this,
@@ -477,10 +477,12 @@ MainWindow::initializeSystemConfig()
           // that is, /usr/local/share/msxpertsuite/massxpert/polChemDefs, for
           // example.
           testDir.setPath(
-            QString("%1/%2").arg(MSXPERTSUITE_DATA_DIR).arg("polChemDefs"));
+            QString("%1/%2").arg(MASSXPERT_DATA_DIR).arg("polChemDefs"));
+          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+                   //<< "From the config.h file:" << testDir.absolutePath();
         }
 
-      if(testDir.exists() && testDir.isAbsolute())
+  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
         {
           // Fantastic, the initial installation directory exists and that is
           // fine.
@@ -495,11 +497,15 @@ MainWindow::initializeSystemConfig()
           // We'll tell the caller that at least one directory was definitely
           // not found.
           ++errorCount;
-
           finalDir = testDir;
+
+          qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
         }
     }
 
+  //QMessageBox::information(
+    //this, "dataDir/polChemDefs path", finalDir.absolutePath(), QMessageBox::Ok);
+
   // And now craft the ConfigSetting instance:
 
   configSetting             = new ConfigSetting(m_moduleName);
@@ -520,11 +526,13 @@ MainWindow::initializeSystemConfig()
 
   testDir.setPath(settings.value("polSeqsDir").toString());
 
-  if(testDir.exists())
+  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
     {
       // Ah ah, the user already configured a new directory. Fine, let's go
       // with it.
       finalDir = testDir;
+      //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+               //<< "From the configSettings file:" << testDir.absolutePath();
     }
   else
     {
@@ -534,7 +542,7 @@ MainWindow::initializeSystemConfig()
           // located. Then, we'll craft the directory by appending
           // "Contents/Resources/data".
 
-          testDir.setPath(QString("%1/../Resources/data/polSeqs")
+          testDir.setPath(QString("%1/../Resources/massxpert/data/polSeqs")
                             .arg(QCoreApplication::applicationDirPath()));
 
           // QMessageBox::information(this,
@@ -549,12 +557,14 @@ MainWindow::initializeSystemConfig()
           // that is, /usr/local/share/msxpertsuite/massxpert/polSeqs, for
           // example.
           testDir.setPath(
-            QString("%1/%2").arg(MSXPERTSUITE_DATA_DIR).arg("polSeqs"));
+            QString("%1/%2").arg(MASSXPERT_DATA_DIR).arg("polSeqs"));
+          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()"
+                   //<< "From the config.h file:" << testDir.absolutePath();
         }
 
       // The path must be absolute and must exist.
 
-      if(testDir.exists() && testDir.isAbsolute())
+  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
         {
           // Fantastic, the initial installation directory exists and that is
           // fine.
@@ -569,11 +579,15 @@ MainWindow::initializeSystemConfig()
           // We'll tell the caller that at least one directory was definitely
           // not found.
           ++errorCount;
-
           finalDir = testDir;
+
+          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
         }
     }
 
+  //QMessageBox::information(
+    //this, "dataDir/polSeqs path", finalDir.absolutePath(), QMessageBox::Ok);
+
   // And now craft the ConfigSetting instance:
 
   configSetting             = new ConfigSetting(m_moduleName);
@@ -592,7 +606,7 @@ MainWindow::initializeSystemConfig()
 
   testDir.setPath(settings.value("docDir").toString());
 
-  if(testDir.exists())
+  if(!testDir.isEmpty() && testDir.exists() && testDir.isAbsolute())
     {
       // Ah ah, the user already configured a new directory. Fine, let's go
       // with it.
@@ -609,6 +623,10 @@ MainWindow::initializeSystemConfig()
           testDir.setPath(
             QString("%1/../doc").arg(QCoreApplication::applicationDirPath()));
 
+          testDir.setPath(QString("%1/../Resources/massxpert/doc")
+                            .arg(QCoreApplication::applicationDirPath()));
+
+
           // QMessageBox::information(this,
           //"dir path",
           // QCoreApplication::applicationDirPath(), QMessageBox::Ok);
@@ -619,9 +637,12 @@ MainWindow::initializeSystemConfig()
 
           // That would be /usr/local/share/doc/msxpertsuite
           // that is, /usr/local/share/doc/msxpertsuite, for example.
-          testDir.setPath(QString("%1").arg(MSXPERTSUITE_DOC_DIR));
+          testDir.setPath(QString("%1").arg(MASSXPERT_DOC_DIR));
         }
 
+      //qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+               //<< "massxpert doc dir: " << QString("%1").arg(MASSXPERT_DOC_DIR);
+
       // The path must be absolute and must exist.
 
       if(testDir.exists() && testDir.isAbsolute())
@@ -641,9 +662,13 @@ MainWindow::initializeSystemConfig()
           ++errorCount;
 
           finalDir = testDir;
+          //qDebug() << __FILE__ << "@" << __LINE__ << __FUNCTION__ << "()";
         }
     }
 
+  //QMessageBox::information(
+    //this, "doc dir path", finalDir.absolutePath(), QMessageBox::Ok);
+
   // And now craft the ConfigSetting instance:
 
   configSetting             = new ConfigSetting(m_moduleName);
