@@ -891,9 +891,9 @@ namespace msXpSmassXpert
 
     // First convert text to SequenceEditorWnd*
     bool ok = false;
-    quintptr seqEdWndCastToInt = text.toInt(&ok);
+    quintptr pointerCastToInt = text.toLongLong(&ok, 10);
 
-    if(seqEdWndCastToInt == 0 || ok == false)
+    if(pointerCastToInt == 0 || ok == false)
       {
         mp_sequenceEditorWnd = 0;
 
@@ -908,10 +908,10 @@ namespace msXpSmassXpert
 		const MainWindow *p_mainWnd = mp_mzLabWnd->mainWindow();
 
     if(p_mainWnd->isSequenceEditorWnd
-       (reinterpret_cast<SequenceEditorWnd *>(seqEdWndCastToInt)))
+       (reinterpret_cast<SequenceEditorWnd *>(pointerCastToInt)))
       {
         mp_sequenceEditorWnd =
-          reinterpret_cast<SequenceEditorWnd *>(seqEdWndCastToInt);
+          reinterpret_cast<SequenceEditorWnd *>(pointerCastToInt);
 
         return mp_sequenceEditorWnd;
       }
