@@ -1,34 +1,35 @@
-/*  BEGIN software license
+/* BEGIN software license
  *
- *  msXpertSuite - mass spectrometry software suite
- *  -----------------------------------------------
- *  Copyright(C) 2009, 2017 Filippo Rusconi
+ * msXpertSuite - mass spectrometry software suite
+ * -----------------------------------------------
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
- *  http://www.msxpertsuite.org
+ * http://www.msxpertsuite.org
  *
- *  This file is part of the msXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- *  The msXpertSuite project is the successor of the massXpert project. This
- *  project now includes various independent modules:
- *  
- *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
- *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * The msXpertSuite project is the successor of the massXpert project. This
+ * project now includes various independent modules:
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
  * END software license
-*/
+ */
+
 
 
 
@@ -46,7 +47,7 @@ namespace msXpSmassXpert
   {
     if (m_kbdShiftDown)
       return SelectPreviousChar(event);
-    
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
 
     if (!m_kbdCtrlDown || !multiRegionSelection)
@@ -54,20 +55,20 @@ namespace msXpSmassXpert
 
     if (m_lastClickedVignette <= 0)
       return event->accept();
-  
+
     --m_lastClickedVignette;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-    m_selectionFirstPoint = 
+
+    m_selectionFirstPoint =
       vignetteLocation(m_lastClickedVignette, CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
 
     positionCursor();
-  
-    QPointF point = 
+
+    QPointF point =
       mapFromScene(vignetteLocation(m_lastClickedVignette, CENTER));
-  
+
     if (point.y() <=(m_requestedVignetteSize / 4))
       vScrollBarActionTriggered(QAbstractSlider::SliderSingleStepSub);
 
@@ -82,7 +83,7 @@ namespace msXpSmassXpert
   {
     if (m_kbdShiftDown)
       return SelectNextChar(event);
-    
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
 
     if (!m_kbdCtrlDown || !multiRegionSelection)
@@ -90,20 +91,20 @@ namespace msXpSmassXpert
 
     if (m_lastClickedVignette >= mp_polymer->size())
       return event->accept();
-  
+
     ++m_lastClickedVignette;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
-    m_selectionFirstPoint = 
+
+    m_selectionFirstPoint =
       vignetteLocation(m_lastClickedVignette, CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
-  
+
     positionCursor();
-  
-    QPointF point = 
+
+    QPointF point =
       mapFromScene(vignetteLocation(m_lastClickedVignette, CENTER));
-  
+
     if (point.y() >= rect().height() -(m_requestedVignetteSize / 4))
       vScrollBarActionTriggered(QAbstractSlider::SliderSingleStepAdd);
 
@@ -118,12 +119,12 @@ namespace msXpSmassXpert
   {
     if (m_kbdShiftDown)
       return SelectPreviousLine(event);
-    
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
 
     if (!m_kbdCtrlDown || !multiRegionSelection)
       resetSelection();
-	      
+
     if (m_lastClickedVignette <= 0)
       return event->accept();
 
@@ -131,20 +132,20 @@ namespace msXpSmassXpert
 
     if (targetIndex < 0)
       return;
-  
+
     m_lastClickedVignette = targetIndex;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
-    m_selectionFirstPoint = 
+
+    m_selectionFirstPoint =
       vignetteLocation(m_lastClickedVignette, CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
-  
+
     positionCursor();
-  
-    QPointF point = 
+
+    QPointF point =
       mapFromScene(vignetteLocation(m_lastClickedVignette, CENTER));
-  
+
     if (point.y() <=(m_requestedVignetteSize / 4))
       vScrollBarActionTriggered(QAbstractSlider::SliderSingleStepSub);
 
@@ -159,12 +160,12 @@ namespace msXpSmassXpert
   {
     if (m_kbdShiftDown)
       return SelectNextLine(event);
-    
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
 
     if (!m_kbdCtrlDown || !multiRegionSelection)
       resetSelection();
-	      
+
     if (m_lastClickedVignette >= mp_polymer->size())
       return event->accept();
 
@@ -172,18 +173,18 @@ namespace msXpSmassXpert
 
     if (targetIndex >= mp_polymer->size())
       return;
-  
+
     m_lastClickedVignette = targetIndex;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
-    m_selectionFirstPoint = 
+
+    m_selectionFirstPoint =
       vignetteLocation(m_lastClickedVignette, CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
 
     positionCursor();
-  
-    QPointF point = 
+
+    QPointF point =
       mapFromScene(vignetteLocation(m_lastClickedVignette, CENTER));
 
     if (point.y() >= rect().height() -(m_requestedVignetteSize / 4))
@@ -200,12 +201,12 @@ namespace msXpSmassXpert
   {
     if (m_kbdShiftDown)
       return SelectPreviousPage(event);
-    
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
 
     if (!m_kbdCtrlDown || !multiRegionSelection)
       resetSelection();
-  
+
     if (m_lastClickedVignette <= 0)
       return event->accept();
 
@@ -218,7 +219,7 @@ namespace msXpSmassXpert
     m_lastClickedVignette = targetIndex;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
+
     m_selectionFirstPoint = vignetteLocation(m_lastClickedVignette,
 					      CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
@@ -228,7 +229,7 @@ namespace msXpSmassXpert
     QScrollBar *vScrollBar = verticalScrollBar();
     int curVal = vScrollBar->value();
     vScrollBar->setValue(curVal -(visibleRows * m_requestedVignetteSize));
-  
+
     mp_editorWnd->updateSelectedSequenceMasses();
 
     return event->accept();
@@ -240,15 +241,15 @@ namespace msXpSmassXpert
   {
     if (m_kbdShiftDown)
       return SelectNextPage(event);
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
 
     if (!m_kbdCtrlDown || !multiRegionSelection)
       resetSelection();
-  
+
     if (m_lastClickedVignette >= mp_polymer->size())
       return event->accept();
-  
+
     int visibleRows = rect().height() / m_requestedVignetteSize;
     int targetIndex = m_lastClickedVignette +(m_columns * visibleRows);
 
@@ -258,7 +259,7 @@ namespace msXpSmassXpert
     m_lastClickedVignette = targetIndex;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
+
     m_selectionFirstPoint = vignetteLocation(m_lastClickedVignette,
 					      CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
@@ -268,7 +269,7 @@ namespace msXpSmassXpert
     QScrollBar *vScrollBar = verticalScrollBar();
     int curVal = vScrollBar->value();
     vScrollBar->setValue(curVal +(visibleRows * m_requestedVignetteSize));
-  
+
     mp_editorWnd->updateSelectedSequenceMasses();
 
     return event->accept();
@@ -279,21 +280,21 @@ namespace msXpSmassXpert
   SequenceEditorGraphicsView::MoveToStartOfLine(QKeyEvent *event)
   {
     resetSelection();
-  
+
     if (m_lastClickedVignette <= 0)
       return event->accept();
 
     double rowIndex = m_lastClickedVignette / m_columns;
     int targetIndex = static_cast<int>(rowIndex) * m_columns;
-  
+
     m_lastClickedVignette = targetIndex;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
-    m_selectionFirstPoint = 
+
+    m_selectionFirstPoint =
       vignetteLocation(m_lastClickedVignette, CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
-   
+
     positionCursor(START_OF_LINE);
 
     mp_editorWnd->updateSelectedSequenceMasses();
@@ -306,17 +307,17 @@ namespace msXpSmassXpert
   SequenceEditorGraphicsView::MoveToEndOfLine(QKeyEvent *event)
   {
     resetSelection();
-  
+
     if (m_lastClickedVignette >= mp_polymer->size())
       return event->accept();
 
     double rowIndex = m_lastClickedVignette / m_columns;
     int targetIndex = static_cast<int>(rowIndex + 1) * m_columns;
-  
+
     m_lastClickedVignette = targetIndex;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
+
     m_selectionFirstPoint = vignetteLocation(m_lastClickedVignette,
 					      CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
@@ -334,20 +335,20 @@ namespace msXpSmassXpert
   {
     if (selectionIndices(static_cast<CoordinateList *>(0)))
       resetSelection();
-  
+
     if (m_lastClickedVignette <= 0)
       return event->accept();
 
     int targetIndex = 0;
-  
+
     m_lastClickedVignette = targetIndex;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
-    m_selectionFirstPoint = 
+
+    m_selectionFirstPoint =
       vignetteLocation(m_lastClickedVignette, CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
-   
+
     positionCursor(START_OF_LINE);
 
     QScrollBar *vScrollBar = verticalScrollBar();
@@ -364,22 +365,22 @@ namespace msXpSmassXpert
   {
     if (selectionIndices(static_cast<CoordinateList *>(0)))
       resetSelection();
-  
+
     if (m_lastClickedVignette >= mp_polymer->size())
       return event->accept();
-  
+
     int targetIndex = mp_polymer->size();
 
     m_lastClickedVignette = targetIndex;
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
-    m_selectionFirstPoint = 
+
+    m_selectionFirstPoint =
       vignetteLocation(m_lastClickedVignette, CENTER);
     m_selectionSecondPoint = m_selectionFirstPoint;
-  
+
     positionCursor(END_OF_LINE);
-  
+
     QScrollBar *vScrollBar = verticalScrollBar();
     vScrollBar->setValue(m_rows * m_requestedVignetteSize);
 
@@ -394,10 +395,10 @@ namespace msXpSmassXpert
   {
     if (m_lastClickedVignette <= 0)
       return event->accept();
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
@@ -405,28 +406,28 @@ namespace msXpSmassXpert
 	--m_lastClickedVignette;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-	
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
       }
     else
       {
-	m_selectionFirstPoint = 
+	m_selectionFirstPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	
+
 	--m_lastClickedVignette;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-	
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
@@ -435,10 +436,10 @@ namespace msXpSmassXpert
       }
 
     positionCursor();
-  
-    QPointF point = 
+
+    QPointF point =
       mapFromScene(vignetteLocation(m_lastClickedVignette, CENTER));
-  
+
     if (point.y() <=(m_requestedVignetteSize / 4))
       vScrollBarActionTriggered(QAbstractSlider::SliderSingleStepSub);
 
@@ -453,10 +454,10 @@ namespace msXpSmassXpert
   {
     if (m_lastClickedVignette >= mp_polymer->size())
       return event->accept();
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
@@ -464,40 +465,40 @@ namespace msXpSmassXpert
 	++m_lastClickedVignette;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
       }
     else
       {
-	m_selectionFirstPoint = 
+	m_selectionFirstPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
 
 	++m_lastClickedVignette;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
-	
+
 	m_ongoingKeyboardMultiSelection = true;
       }
-    
+
     positionCursor();
-  
-    QPointF point = 
+
+    QPointF point =
       mapFromScene(vignetteLocation(m_lastClickedVignette, CENTER));
-  
+
     if (point.y() >= rect().height() -(m_requestedVignetteSize / 4))
       vScrollBarActionTriggered(QAbstractSlider::SliderSingleStepAdd);
 
@@ -517,10 +518,10 @@ namespace msXpSmassXpert
 
     if (targetIndex >= mp_polymer->size())
       return;
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
@@ -528,38 +529,38 @@ namespace msXpSmassXpert
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-	  
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
-      } 
+      }
     else
       {
-	m_selectionFirstPoint = 
+	m_selectionFirstPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-	
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
 
 	m_ongoingKeyboardMultiSelection = true;
       }
-  
+
     positionCursor();
 
-    QPointF point = 
+    QPointF point =
       mapFromScene(vignetteLocation(m_lastClickedVignette, CENTER));
 
     if (point.y() >= rect().height() -(m_requestedVignetteSize / 4))
@@ -576,44 +577,44 @@ namespace msXpSmassXpert
   {
     if (m_lastClickedVignette <= 0)
       return event->accept();
-  
+
     int targetIndex = m_lastClickedVignette - m_columns;
-  
+
     if (targetIndex < 0)
       return;
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
-	
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-	
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
-      } 
+      }
     else
       {
-	m_selectionFirstPoint = 
+	m_selectionFirstPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-      
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
@@ -622,10 +623,10 @@ namespace msXpSmassXpert
       }
 
     positionCursor();
-  
-    QPointF point = 
+
+    QPointF point =
       mapFromScene(vignetteLocation(m_lastClickedVignette, CENTER));
-  
+
     if (point.y() <=(m_requestedVignetteSize / 4))
       vScrollBarActionTriggered(QAbstractSlider::SliderSingleStepSub);
 
@@ -646,39 +647,39 @@ namespace msXpSmassXpert
 
     if (targetIndex >= mp_polymer->size())
       targetIndex = mp_polymer->size();
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
-	
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
-      } 
+      }
     else
       {
-	m_selectionFirstPoint = 
+	m_selectionFirstPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-      
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
@@ -687,7 +688,7 @@ namespace msXpSmassXpert
       }
 
     positionCursor();
-  
+
     QScrollBar *vScrollBar = verticalScrollBar();
     int curVal = vScrollBar->value();
     vScrollBar->setValue(curVal +(visibleRows * m_requestedVignetteSize));
@@ -709,47 +710,47 @@ namespace msXpSmassXpert
 
     if (targetIndex < 0)
       targetIndex = 0;
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
-	
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
-      } 
+      }
     else
       {
-	m_selectionFirstPoint = 
+	m_selectionFirstPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-      
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
 
 	m_ongoingKeyboardMultiSelection = true;
       }
-  
+
     positionCursor();
-  
+
     QScrollBar *vScrollBar = verticalScrollBar();
     int curVal = vScrollBar->value();
     vScrollBar->setValue(curVal -(visibleRows * m_requestedVignetteSize));
@@ -768,45 +769,45 @@ namespace msXpSmassXpert
 
     double rowIndex = m_lastClickedVignette / m_columns;
     int targetIndex = static_cast<int>(rowIndex) * m_columns;
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
-	
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
+
 	m_selectionSecondPoint = vignetteLocation(m_lastClickedVignette,
 						   CENTER);
-	
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
-      } 
+      }
     else
       {
 	m_selectionFirstPoint = vignetteLocation(m_lastClickedVignette,
 						  CENTER);
-      
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
+
 	m_selectionSecondPoint = vignetteLocation(m_lastClickedVignette,
 						   CENTER);
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
 
 	m_ongoingKeyboardMultiSelection = true;
       }
-  
+
     positionCursor(START_OF_LINE);
 
     mp_editorWnd->updateSelectedSequenceMasses();
@@ -823,49 +824,49 @@ namespace msXpSmassXpert
 
     double rowIndex = m_lastClickedVignette / m_columns;
     int targetIndex = static_cast<int>(rowIndex + 1) * m_columns;
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
-	
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
-      } 
+      }
     else
       {
-	m_selectionFirstPoint = 
+	m_selectionFirstPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-      
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
 
 	m_ongoingKeyboardMultiSelection = true;
       }
-  
+
     positionCursor(END_OF_LINE);
 
-    QPointF point = 
+    QPointF point =
       mapFromScene(vignetteLocation(m_lastClickedVignette, CENTER));
 
     if (point.y() >= rect().height() -(m_requestedVignetteSize / 4))
@@ -882,41 +883,41 @@ namespace msXpSmassXpert
   {
     if (m_lastClickedVignette <= 0)
       return event->accept();
-  
+
     int targetIndex = 0;
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
-	
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-	  
+
 	m_selectionSecondPoint = vignetteLocation(m_lastClickedVignette,
 						   CENTER);
-	
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
-      } 
+      }
     else
       {
 	m_selectionFirstPoint = vignetteLocation(m_lastClickedVignette,
 						  CENTER);
-      
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
+
 	m_selectionSecondPoint = vignetteLocation(m_lastClickedVignette,
 						   CENTER);
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
@@ -940,50 +941,50 @@ namespace msXpSmassXpert
   {
     if (m_lastClickedVignette >= mp_polymer->size())
       return event->accept();
-  
+
     int targetIndex = mp_polymer->size();
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
-	
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-	
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
-      } 
+      }
     else
       {
-	m_selectionFirstPoint = 
+	m_selectionFirstPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
-      
+
 	m_lastClickedVignette = targetIndex;
 // 	qDebug() << __FILE__ << __LINE__
 // 		  << "m_lastClickedVignette:" << m_lastClickedVignette;
-      
-	m_selectionSecondPoint = 
+
+	m_selectionSecondPoint =
 	  vignetteLocation(m_lastClickedVignette, CENTER);
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
 
 	m_ongoingKeyboardMultiSelection = true;
       }
-  
+
     positionCursor(END_OF_LINE);
-  
+
     QScrollBar *vScrollBar = verticalScrollBar();
     vScrollBar->setValue(m_rows * m_requestedVignetteSize);
 
@@ -997,41 +998,41 @@ namespace msXpSmassXpert
   SequenceEditorGraphicsView::SelectAll(QKeyEvent *event)
   {
     m_lastClickedVignette = 0;
-  
+
     m_selectionFirstPoint = vignetteLocation(m_lastClickedVignette,
 					      CENTER);
 
-    m_lastClickedVignette = mp_polymer->size();;
+    m_lastClickedVignette = mp_polymer->size();
 //     qDebug() << __FILE__ << __LINE__
 // 	      << "m_lastClickedVignette:" << m_lastClickedVignette;
-  
+
     m_selectionSecondPoint = vignetteLocation(m_lastClickedVignette,
 					       CENTER);
-  
+
     bool multiRegionSelection = mp_editorWnd->isMultiRegionSelection();
     bool multiSelectionRegion = mp_editorWnd->isMultiSelectionRegion();
-    
+
     if (m_ongoingKeyboardMultiSelection)
       {
 	mpa_selection->deselectLastRegion();
 
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
       }
     else
       {
-	mpa_selection->selectRegion(m_selectionFirstPoint, 
+	mpa_selection->selectRegion(m_selectionFirstPoint,
 				     m_selectionSecondPoint,
 				     multiRegionSelection,
 				     multiSelectionRegion);
 
 	m_ongoingKeyboardMultiSelection = true;
       }
-  
+
     positionCursor(END_OF_LINE);
-  
+
     QScrollBar *vScrollBar = verticalScrollBar();
     vScrollBar->setValue(m_rows * m_requestedVignetteSize);
 
