@@ -301,6 +301,12 @@ AbstractPlotWidget::showGraphData(std::size_t plotTraceIndex)
   m_currentPlotTraceIndex = plotTraceIndex;
 
   replot();
+
+  // We need to update the correcponding trace in the multiGraph plot widget...
+  mp_multiGraph->setData(QVector<double>::fromList(currentTrace->keyList()),
+			 	QVector<double>::fromList(currentTrace->valList()));
+	mp_multiGraph->parentPlot()->replot();
+
 }
 
 
@@ -1746,6 +1752,7 @@ AbstractPlotWidget::applySavitzkyGolay()
 
   // We need to update the correcponding trace in the multiGraph plot widget...
   mp_multiGraph->setData(keyVector, filteredValues);
+	mp_multiGraph->parentPlot()->replot();
 }
 
 
