@@ -51,23 +51,24 @@
 #include <qcustomplot.h>
 
 /////////////////////// Local includes
-#include <minexpert/gui/MainWindow.hpp>
-#include <minexpert/nongui/globals.hpp>
-#include <minexpert/gui/AboutMineXpertDlg.hpp>
-#include <minexpert/gui/Application.hpp>
-#include <libmass/MassSpectrum.hpp>
+#include "MainWindow.hpp"
+#include "../nongui/globals.hpp"
+#include "AboutMineXpertDlg.hpp"
+#include "Application.hpp"
+#include "../../libmass/MassSpectrum.hpp"
 
-#include <minexpert/gui/AbstractMultiPlotWnd.hpp>
+#include "AbstractMultiPlotWnd.hpp"
 
-#include <minexpert/nongui/MassSpecDataFileFormatAnalyzer.hpp>
-#include <minexpert/nongui/MassSpecDataFileLoaderSqlite3.hpp>
-#include <minexpert/nongui/MassSpecDataFileLoaderPwiz.hpp>
-#include <minexpert/nongui/MassSpecDataFileLoaderPwiz.hpp>
-#include <minexpert/nongui/MassSpecDataFileLoaderMs1.hpp>
-#include <minexpert/nongui/MassSpecDataFileLoaderXy.hpp>
-#include <minexpert/nongui/MassSpecDataFileLoaderBrukerXy.hpp>
-#include <minexpert/nongui/MassSpecDataFileLoaderDx.hpp>
-#include <minexpert/gui/ScriptingWnd.hpp>
+#include "../nongui/MassSpecDataFileFormatAnalyzer.hpp"
+#include "../nongui/MassSpecDataFileLoaderSqlite3.hpp"
+#include "../nongui/MassSpecDataFileLoaderPwiz.hpp"
+#include "../nongui/MassSpecDataFileLoaderPwiz.hpp"
+#include "../nongui/MassSpecDataFileLoaderMs1.hpp"
+#include "../nongui/MassSpecDataFileLoaderXy.hpp"
+#include "../nongui/MassSpecDataFileLoaderBrukerXy.hpp"
+#include "../nongui/MassSpecDataFileLoaderDx.hpp"
+#include "PeakShaperDlg.hpp"
+#include "ScriptingWnd.hpp"
 
 
 namespace msXpSmineXpert
@@ -608,35 +609,24 @@ MainWindow::openStreamedMassSpectrometryFileDlg()
 
 //! Create a mass spectrum starting from data in the clipboard.
 void
-MainWindow::createMassSpectrumFromClipboard()
+MainWindow::createMassSpectrumFromXyText(const QString &text, const QString &title)
 {
-  QClipboard *clipboard = QGuiApplication::clipboard();
-  QString msData        = clipboard->text();
-
-	//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-		//<< "msData:" << msData;
-
-  if(msData.isEmpty())
+  if(text.isEmpty())
     {
-      QMessageBox msgBox;
-      msgBox.setText("Failed to get data from the clipboard.");
-
-      msgBox.setStandardButtons(QMessageBox::Ok);
-      msgBox.exec();
+      return;
     }
 
   logConsoleMessage(
-    "Starting the parsing of the mass data text from clipboard.\n");
+    "Starting the parsing of the mass data text.\n");
 
   MassSpecDataFileLoaderXy loader;
 
-
   // This data set will be reparented when we provide it to the handling
   // widget (window or plot widget or whatever QObject).
   MassSpecDataSet *p_massSpecDataSet =
-    new MassSpecDataSet(this, "NOT_SET", "NOT_SET", false);
+    new MassSpecDataSet(this, "NOT_SET", title, false);
 
-  if(loader.loadDataFromString(msData, p_massSpecDataSet) < 1)
+  if(loader.loadDataFromString(text, p_massSpecDataSet) < 1)
     {
       statusBarMessage("Failed to load any mass spectrum.");
       delete p_massSpecDataSet;
@@ -714,6 +704,19 @@ MainWindow::createMassSpectrumFromClipboard()
 }
 
 
+//! Create a mass spectrum starting from data in the clipboard.
+void
+MainWindow::createMassSpectrumFromClipboard()
+{
+  QClipboard *clipboard = QGuiApplication::clipboard();
+  QString msData        = clipboard->text();
+
+
+	return createMassSpectrumFromXyText(msData, QString("From clipboard @ %1")
+			.arg(QTime::currentTime().toString("hh:mm:ss.zzz")));
+}
+
+
 /*/js/
  * MainWindow.jsCreateMassSpectrumFromClipboard()
  *
@@ -850,14 +853,14 @@ MainWindow::initialTicDone(AbstractPlotWidget *widget,
     showMzIntegrationParamsHelp(
       massSpecDataSet->statistics().m_smallestStepMedian);
 
-	// At this point, if the tic data contain a single point, then, start the
-	// integration to the masss spectrum right away.
-	
-	//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-		//"hash size: " << massSpecDataSet->rtHash().size();
+  // At this point, if the tic data contain a single point, then, start the
+  // integration to the masss spectrum right away.
 
-	if(massSpecDataSet->rtHash().size() < 2)
-		static_cast<TicChromPlotWidget *>(widget)->integrateToMz();
+  // qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
+  //"hash size: " << massSpecDataSet->rtHash().size();
+
+  if(massSpecDataSet->rtHash().size() < 2)
+    static_cast<TicChromPlotWidget *>(widget)->integrateToMz();
 }
 
 
@@ -1736,6 +1739,17 @@ MainWindow::makeLoaderConnections(MassSpecDataFileLoader *loader)
 }
 
 
+void
+MainWindow::peakShaperDlg()
+{
+  PeakShaperDlg *peak_shaper_dlg_p =
+    new PeakShaperDlg(dynamic_cast<QWidget *>(this), m_moduleName);
+  peak_shaper_dlg_p->show();
+  peak_shaper_dlg_p->raise();
+  peak_shaper_dlg_p->activateWindow();
+}
+
+
 //! Open the analysis preferences dialog window to let the user configure the
 //! options.
 void
@@ -1892,6 +1906,19 @@ MainWindow::createMenusAndActions()
   m_plotMenu->addAction(m_clearPlotsAct);
 
 
+  // Utilities menu
+  m_utilitiesMenu = menuBar()->addMenu("&Utilities");
+
+  m_peakShaperAct =
+    new QAction("Centroid peak shaper", dynamic_cast<QObject *>(this));
+  m_peakShaperAct->setShortcut(QKeySequence("Ctrl+U, S"));
+  m_peakShaperAct->setStatusTip(
+    tr("Shape centroid peak(s) into gaussian/lorentzian peak shape(s)"));
+  connect(
+    m_peakShaperAct, &QAction::triggered, this, &MainWindow::peakShaperDlg);
+  m_utilitiesMenu->addAction(m_peakShaperAct);
+
+
   // Windows menu
   m_windowsMenu = menuBar()->addMenu("&Windows");
 
