@@ -79,6 +79,9 @@ namespace msXpSmineXpert
 			//! Last Mr value that was computed.
 			double m_lastMass = qSNaN();
 
+			//! Last resolving power value that was computed.
+			double m_lastResolvingPower = std::numeric_limits<double>::min();
+
 			//! Tolerance on the charge fractional part during deconvolutions.
 			/*:
 
@@ -117,6 +120,8 @@ namespace msXpSmineXpert
 			bool deconvoluteIsotopicCluster();
 			bool deconvoluteChargedState(int span = 1);
 
+			bool computeResolvingPower();
+
 			void mouseMoveHandler(QMouseEvent *event) override;
 			void mouseReleaseHandledEvent(QMouseEvent *event) override;
 
@@ -143,15 +148,9 @@ signals:
 			void newDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history, QColor color);
 
-			void jsNewDriftSpectrum(const MassSpecDataSet *massSpecDataSet,
-					const QString &msg, const History &history, QColor color);
-
 			void newTicChromatogram(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history, QColor color);
 
-			void jsNewTicChromatogram(const MassSpecDataSet *massSpecDataSet,
-					const QString &msg, const History &history, QColor color);
-
 			void ticIntensitySignal(const MassSpecDataSet *massSpecDataSet,
 					const QString &msg, const History &history);
 	};
