@@ -4,7 +4,7 @@
  * -----------------------------------------------
  * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
- * http://www.msxpertsuite.org
+ * http://www.minexpert.org
  *
  * This file is part of the msXpertSuite project.
  *
@@ -53,10 +53,10 @@
 
 
 /////////////////////// Local includes
-#include <config.h>
-#include <minexpert/gui/Application.hpp>
-#include <minexpert/nongui/CommandLineRunner.hpp>
-#include <minexpert/gui/MainWindow.hpp>
+#include "../config.h"
+#include "gui/Application.hpp"
+#include "nongui/CommandLineRunner.hpp"
+#include "gui/MainWindow.hpp"
 
 
 using std::cout;
@@ -128,13 +128,15 @@ namespace msXpSmineXpert
 			QString config = QObject::tr("mineXpert: "
 					"Compiled with the following configuration:\n"
 					"EXECUTABLE BINARY FILE: = %1\n"
-					"MSXPERTSUITE_BIN_DIR = %2\n"
-					"MSXPERTSUITE_DATA_DIR = %3\n"
-					"MSXPERTSUITE_DOC_DIR = %5\n")
+					"MINEXPERT_BIN_DIR = %2\n"
+					"MINEXPERT_JAVASCRIPT_DIR = %2\n"
+					"MINEXPERT_DATA_DIR = %3\n"
+					"MINEXPERT_DOC_DIR = %5\n")
 				.arg(execName)
-				.arg(MSXPERTSUITE_BIN_DIR)
-				.arg(MSXPERTSUITE_DATA_DIR)
-				.arg(MSXPERTSUITE_DOC_DIR);
+				.arg(MINEXPERT_BIN_DIR)
+				.arg(MINEXPERT_JAVASCRIPT_DIR)
+				.arg(MINEXPERT_DATA_DIR)
+				.arg(MINEXPERT_DOC_DIR);
 
 			cout << config.toStdString();
 		}
@@ -269,7 +271,7 @@ main(int argc, char **argv)
 		if(isPrintConfig)
 		{
 			msXpSmineXpert::printConfig(QString("%1 (run as %2)")
-					.arg(MINEXPERT_TARGET)
+					.arg(MINEXPERT_TARGET_NAME)
 					.arg(argv[0]));
 			return 0;
 		}
