@@ -398,11 +398,11 @@ namespace msXpSmineXpert
 						__FILE__, __LINE__, __FUNCTION__);
 			}
 
-			// Look if the table has already an identical record.
+			 //qDebug() << __FILE__ << __LINE__
+			 //<< "writeDbDriftData: "
+			 //<< "driftTime: " << driftTime;
 
-			 qDebug() << __FILE__ << __LINE__
-			 << "writeDbDriftData: "
-			 << "driftTime: " << driftTime;
+			// Look if the table has already an identical record.
 
 
 			QSqlQuery *sqlQuery = new QSqlQuery(database);
