@@ -58,7 +58,22 @@ namespace msXpSmineXpert
 
 
 	/*/js/ Class: SavGolFilter
-	*/
+	 * <comment>This class handles the parameterization of the Savitzky-Golay
+	 * filter. This filter is an efficient way to remove noise from noisy mass
+	 * spectra and can be automatically applied after any mass spectrum
+	 * combination processing.
+	 *
+	 * A SavGolFilter object contains the following member data as members of a
+	 * <SavGolParams> object (see documentation for SavGolParams):
+	 * - nl: <Number> of points on the left of the filtered point;
+	 * - nR: <Number of points on the right of the filtered point;
+	 * - m:	 <Number> (order) of the polynomial to use in the regression analysis
+	 *   leading to the Savitzky-Golay coefficients (typically between 2 and 6);
+	 * - lD: <Number> specifying the order of the derivative to extract from the
+	 *   Savitzky-Golay smoothing algorithm (for regular smoothing, use 0)
+	 * - convolveWithNr <Boolean>  Set to false for best results
+	 * </comment>
+	 */
 
 
 	SavGolFilterJs::SavGolFilterJs(QScriptEngine *engine)
@@ -125,6 +140,14 @@ namespace msXpSmineXpert
 	 * SavGolFilter()
 	 *
 	 * Constructor of a SavGolFilter object
+	 *
+	 * Ex:
+	 * var sgf1 = new SavGolFilter();
+	 * sgf1.nL; // --> 15
+	 * sgf1.nR; // --> 15
+	 * sgf1.m; // --> 4
+	 * sgf1.lD; // --> 0
+	 * sgf1.convolveWithNr; // --> false
 	 */
 	QScriptValue
 		SavGolFilterJs::newInstance()
@@ -141,6 +164,20 @@ namespace msXpSmineXpert
 	 * Constructor of a SavGolFilter object initialized using a <SavGolParams>
 	 * object
 	 *
+	 * Ex:
+	 *
+	 * var sgp1 = new SavGolParams();
+	 *
+	 * sgp1.nL = 10; --> 10
+	 * sgp1.nR = 10; --> 10
+	 * sgp1.lD = 0; --> 0
+	 * sgp1.m = 5; --> 5
+	 *
+	 * var sgf1 = new SavGolFilter(sgp1);
+	 * sgf1.asText(); --> output is:
+	 *
+	 * Savitzy-Golay filter parameters:
+	 * nL: 10 ; nR: 10 ; m: 5 ; lD: 0 ; convolveWithNr : false
 	 * savGolParams: <SavGolParams> object to be used to initialize this object's SavGolParams
 	 */
 	QScriptValue
@@ -158,17 +195,26 @@ namespace msXpSmineXpert
 	 * Constructor of a SavGolFilter object initialized using parameters that
 	 * initialize the SavGolParams member object
 	 *
-	 * nL: number of data points on the left of the point being filtered
+	 * nL: number of data points on the left of the point being filtered (default * 15)
 	 *
-	 * nR: number of data points on the right of the point being filtered
+	 * nR: number of data points on the right of the point being filtered (default * 15)
 	 *
 	 * m: order of the polynomial to use in the regression analysis
-	 * leading to the Savitzky-Golay coefficients (typicall [2-6])
+	 * leading to the Savitzky-Golay coefficients (typicall [2-6], default 4)
 	 *
 	 * lD: order of the derivative to extract from the Savitzky-Golay
-	 * smoothing algorithm (for regular smoothing, use 0);
+	 * smoothing algorithm (for regular smoothing, use 0, the default);
 	 *
-	 * convolveWithNr: set to false for best results
+	 * Ex:
+	 *
+	 * var sgf1 = new SavGolFilter(10, 10, 6, 0, true);
+	 *
+	 * sgf1.asText(); --> output is:
+	 *
+	 * Savitzy-Golay filter parameters:
+	 * nL: 10 ; nR: 10 ; m: 6 ; lD: 0 ; convolveWithNr : true
+	 *
+	 * convolveWithNr: set to false for best results (default false)
 	 */
 	QScriptValue
 		SavGolFilterJs::newInstance(int nL, int nR, int m, int lD, bool convolveWithNr)
@@ -184,6 +230,24 @@ namespace msXpSmineXpert
 	 *
 	 * Constructor of a SavGolFilter object
 	 *
+	 * Ex:
+	 *
+	 * var sgf1 = new SavGolFilter();
+	 * sgf1.asText(); --> output is:
+	 *
+	 * Savitzy-Golay filter parameters:
+	 * nL: 15 ; nR: 15 ; m: 4 ; lD: 0 ; convolveWithNr : false*
+	 *
+	 * sgf1.nL = 10;
+	 * sgf1.nR = 10;
+	 * sgf1.m= 6;
+	 *
+	 * var sgf2 = new SavGolFilter(sgf1);
+	 * sgf2.asText(); --> output is:
+	 *
+	 * Savitzy-Golay filter parameters:
+	 * nL: 10 ; nR: 10 ; m: 6 ; lD: 0 ; convolveWithNr : false
+	 *
 	 * savGolFilter: <SavGolFilter> object to be used to initialize this object
 	 */
 	QScriptValue
@@ -273,30 +337,125 @@ namespace msXpSmineXpert
 
 			if(name == nL)
 			{
+				/*js/
+				 * SavGolFilter.nL
+				 *
+				 * Return the <Number> property nL.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.nL; // --> 15
+				 */
 				return QScriptValue(savGolFilter->m_savGolParams.nL);
 			}
 			else if(name == nR)
 			{
+				/*js/
+				 * SavGolFilter.nR
+				 *
+				 * Return the <Number> property nR.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.nR; // --> 15
+				 */
 				return QScriptValue(savGolFilter->m_savGolParams.nR);
 			}
 			else if(name == m)
 			{
+				/*js/
+				 * SavGolFilter.m
+				 *
+				 * Return the <Number> property m.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.m; // --> 4
+				 */
 				return QScriptValue(savGolFilter->m_savGolParams.m);
 			}
 			else if(name == lD)
 			{
+				/*js/
+				 * SavGolFilter.lD
+				 *
+				 * Return the <Number> property lD.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.lD; // --> 0
+				 */
 				return QScriptValue(savGolFilter->m_savGolParams.lD);
 			}
 			else if(name == convolveWithNr)
 			{
+				/*js/
+				 * SavGolFilter.convolveWithNr
+				 *
+				 * Return the <Boolean> property convolveWithNr.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.convolveWithNr; // --> false;
+				 */
 				return QScriptValue(savGolFilter->m_savGolParams.convolveWithNr);
 			}
 			else if(name == savGolParams)
 			{
+				/*js/
+				 * SavGolFilter.savGolParams
+				 *
+				 * Return a <SavGolParams> object containing this object's SavGolParams
+				 * values
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 * sgf1.nL; --> 15
+				 * sgf1.nR; --> 15
+				 * sgf1.m; --> 4
+				 * sgf1.lD; --> 0
+				 * sgf1.convolveWithNr; --> false
+				 * sgf1.nL =1;
+				 * sgf1.nR =1;
+				 * sgf1.m =3;
+				 * sgf1.lD =1;
+				 * sgf1.convolveWithNr = true;
+				 * sgf1.asText();
+				 *
+				 * Savitzy-Golay filter parameters:
+				 * nL: 1 ; nR: 1 ; m: 3 ; lD: 1 ; convolveWithNr : true
+				 *
+				 * var sgp1 = sgf1.savGolParams;
+				 * sgp1.nL; --> 1
+				 * sgp1.nR; --> 1
+				 * sgp1.m; --> 3
+				 * sgp1.lD; --> 1
+				 * sgp1.convolveWithNr; -> true
+				 */
 				return toScriptValue(engine(), savGolFilter->m_savGolParams);
 			}
 			else if(name == samples)
 			{
+				/*js/
+				 *
+				 * Return the number of samples to filter
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 * sgf1.samples; --> 0
+				 */
 				return QScriptValue(savGolFilter->m_samples);
 			}
 
@@ -314,26 +473,111 @@ namespace msXpSmineXpert
 
 			if(name == nL)
 			{
-				savGolFilter->m_savGolParams.nL = qscriptvalue_cast<msXpS::BinningType>(value);
+				/*js/
+				 * SavGolFilter.nL = <Number>
+				 *
+				 * Set the <Number> property nL.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.nL = 14;
+				 *
+				 * sgf1.nL; // --> 14
+				 */
+				savGolFilter->m_savGolParams.nL = qscriptvalue_cast<int>(value);
 			}
 			else if(name == nR)
 			{
-				savGolFilter->m_savGolParams.nR = qscriptvalue_cast<double>(value);
+				/*js/
+				 * SavGolFilter.nL = <Number>
+				 *
+				 * Set the <Number> property nL.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.nL = 14;
+				 *
+				 * sgf1.nL; // --> 14
+				 */
+				savGolFilter->m_savGolParams.nR = qscriptvalue_cast<int>(value);
 			}
 			else if(name == m)
 			{
-				savGolFilter->m_savGolParams.m = qscriptvalue_cast<msXpS::MassToleranceType>(value);
+				/*js/
+				 * SavGolFilter.m = <Number>
+				 *
+				 * Set the <Number> property m.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.m = 6;
+				 *
+				 * sgf1.m; // --> 6
+				 */
+				savGolFilter->m_savGolParams.m = qscriptvalue_cast<int>(value);
 			}
 			else if(name == lD)
 			{
-				savGolFilter->m_savGolParams.lD = qscriptvalue_cast<bool>(value);
+				/*js/
+				 * SavGolFilter.lD = <Number>
+				 *
+				 * Set the <Number> property lD.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.lD = 1;
+				 *
+				 * sgf1.lD; // --> 1
+				 */
+				savGolFilter->m_savGolParams.lD = qscriptvalue_cast<int>(value);
 			}
 			else if(name == convolveWithNr)
 			{
+				/*js/
+				 * SavGolFilter.convolveWithNr = <Number>
+				 *
+				 * Set the <Boolean> property convolveWithNr.
+				 *
+				 * Ex:
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 *
+				 * sgf1.convolveWithNr = true;
+				 *
+				 * sgf1.convolveWithNr; // --> true
+				 */
 				savGolFilter->m_savGolParams.convolveWithNr = qscriptvalue_cast<bool>(value);
 			}
 			else if(name == savGolParams)
 			{
+				/*js/
+				 *
+				 * Set the SavGolParams values from a <SavGolParams> object
+				 *
+				 * Ex:
+				 *
+				 * var sgp1 =  new SavGolParams;
+				 * sgp1.nL = 10;
+				 * sgp1.nR = 10;
+				 * sgp1.m = 6;
+				 * sgp1.lD = 1;
+				 * sgp1.convolveWithNr = true;
+				 *
+				 * var sgf1 = new SavGolFilter();
+				 * sgf1.savGolParams = sgp1;
+				 * sgf1.asText(); --> output is:
+				 *
+				 * Savitzy-Golay filter parameters:
+				 * nL: 10 ; nR: 10 ; m: 6 ; lD: 1 ; convolveWithNr : true
+				 */
 				savGolFilter->m_savGolParams = qscriptvalue_cast<SavGolParams>(value);
 			}
 
@@ -354,7 +598,7 @@ namespace msXpSmineXpert
 				return QScriptValue();
 
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "Found the SavGolFilterJs class.";
+			//<< "Found the SavGolFilterJs class.";
 
 			int argCount = ctx->argumentCount();
 
@@ -392,7 +636,7 @@ namespace msXpSmineXpert
 						SavGolParams params = qscriptvalue_cast<SavGolParams>(arg);
 
 						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-							//<< "We are constructing from SavGolParams.";
+						//<< "We are constructing from SavGolParams.";
 
 						return cls->newInstance(params);
 					}
@@ -403,14 +647,14 @@ namespace msXpSmineXpert
 				if(variant.userType() == QMetaType::type("msXpSmineXpert::SavGolFilter"))
 				{
 					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__<< "()"
-						//<< "The argument passed to the constructor is a SavGolFilter.";
+					//<< "The argument passed to the constructor is a SavGolFilter.";
 
 					return cls->newInstance(qscriptvalue_cast<SavGolFilter>(arg));
 				}
 				else if(variant.userType() == QMetaType::type("msXpSmineXpert::SavGolParams"))
 				{
 					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__<< "()"
-						//<< "The argument passed to the constructor is a SavGolParams structure.";
+					//<< "The argument passed to the constructor is a SavGolParams structure.";
 
 					return cls->newInstance(qscriptvalue_cast<SavGolParams>(arg));
 				}
@@ -492,11 +736,12 @@ namespace msXpSmineXpert
 		}
 
 
+	// See, for the JS-doc the SavGolParamsJSDoc.cpp file
 	QScriptValue
 		SavGolFilterJs::SavGolParamsCtor(QScriptContext *ctx, QScriptEngine *engine)
 		{
 			//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-				//<< "with backtrace:" << ctx->backtrace();
+			//<< "with backtrace:" << ctx->backtrace();
 
 			int argCount = ctx->argumentCount();
 
@@ -524,7 +769,7 @@ namespace msXpSmineXpert
 					SavGolParams params = qscriptvalue_cast<SavGolParams>(arg);
 
 					//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-						//<< "We are constructing from SavGolParams.";
+					//<< "We are constructing from SavGolParams.";
 
 					return engine->toScriptValue(params);
 				}
@@ -542,7 +787,7 @@ namespace msXpSmineXpert
 						SavGolFilter filter = qscriptvalue_cast<SavGolFilter>(arg);
 
 						//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-							//<< "We are constructing from SavGolFilter.";
+						//<< "We are constructing from SavGolFilter.";
 
 						return engine->toScriptValue(filter);
 					}
@@ -562,7 +807,7 @@ namespace msXpSmineXpert
 				// We are constructing from raw values.
 
 				//qDebug() << __FILE__ << __LINE__ << __FUNCTION__ << "()"
-					//<< "We are constructing from raw values.";
+				//<< "We are constructing from raw values.";
 
 				QScriptValue nLJSValue = ctx->argument(0);
 				QScriptValue nRJSValue = ctx->argument(1);
@@ -570,19 +815,21 @@ namespace msXpSmineXpert
 				QScriptValue lDJSValue = ctx->argument(3);
 				QScriptValue convolveWithNrJSValue = ctx->argument(4);
 
-				SavGolParams params{static_cast<int>(nLJSValue.toNumber()),
-					static_cast<int>(nRJSValue.toNumber()),
-					static_cast<int>(mJSValue.toNumber()),
-					static_cast<int>(lDJSValue.toNumber()),
-					convolveWithNrJSValue.toBoolean()};
+				SavGolParams params;
 
-				return engine->toScriptValue(params);
-			}
+				params.nL = static_cast<int>(nLJSValue.toNumber());
+				params.nR =	static_cast<int>(nRJSValue.toNumber());
+				params.m =	static_cast<int>(mJSValue.toNumber());
+				params.lD =	static_cast<int>(lDJSValue.toNumber());
+				params.convolveWithNr = convolveWithNrJSValue.toBoolean();
 
-			SavGolParams params;
 			return engine->toScriptValue(params);
 		}
 
+	SavGolParams params;
+	return engine->toScriptValue(params);
+}
+
 
 } // namespace msXpSmineXpert
 
