@@ -1,37 +1,38 @@
-/*  BEGIN software license
+/* BEGIN software license
  *
- *  msXpertSuite - mass spectrometry software suite
- *  -----------------------------------------------
- *  Copyright(C) 2009, 2017 Filippo Rusconi
+ * msXpertSuite - mass spectrometry software suite
+ * -----------------------------------------------
+ * Copyright(C) 2009,...,2018 Filippo Rusconi
  *
- *  http://www.msxpertsuite.org
+ * http://www.msxpertsuite.org
  *
- *  This file is part of the msXpertSuite project.
+ * This file is part of the msXpertSuite project.
  *
- *  The msXpertSuite project is the successor of the massXpert project. This
- *  project now includes various independent modules:
- *  
- *  - massXpert, model polymer chemistries and simulate mass spectrometric data;
- *  - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
+ * The msXpertSuite project is the successor of the massXpert project. This
+ * project now includes various independent modules:
  *
- *  This program is free software: you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation, either version 3 of the License, or
- *  (at your option) any later version.
+ * - massXpert, model polymer chemistries and simulate mass spectrometric data;
+ * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
  *
- *  This program is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * This program is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see <http://www.gnu.org/licenses/>.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
- * 
  * END software license
  */
 
 
 
+
 #pragma once
 
 /////////////////////// Qt includes
@@ -56,7 +57,7 @@ namespace msXpSmineXpert
 */
 	enum SliceType
 	{
-		SLICE_NOT_SET,
+		SLICE_NOT_SET = 0,
 		/*!< The slicing method is not set.*/
 		SLICE_ZOOMED_REGION,
 		/*!< The slice contains only the data visible in a zoomed region.*/
@@ -67,11 +68,11 @@ namespace msXpSmineXpert
 	};
 
 
-	//! The SliceSpecif structure configure a mass data slicing operation.
+	//! The SliceSpecif structure configures a mass data slice.
 	/*!
 
-		This structure allows to define some characteristics of the slicing
-		operation using class SqlMassDataSlicer. 
+		This structure allows to define some characteristics of the slice
+		to be created using a SqlMassDataSlicer object.
 
 */
 	struct SliceSpecif
@@ -97,7 +98,7 @@ namespace msXpSmineXpert
 
 		The slicing operation is typically performed by selecting in a plot a region
 		of interest and then calling the slicing dialog. The data slicing operation
-		may be carried over in different ways: 
+		may be carried over in different ways:
 
 		- by defining the number of slices. In this case the slice size will be
 		dependent on the size of the data range selected for the slicing
@@ -113,20 +114,13 @@ namespace msXpSmineXpert
 */
 	class SqlMassDataSlicer : public QObject
 	{
-		Q_OBJECT
+		Q_OBJECT;
+
+		friend class SqlMassDataSlicerJs;
 
-			friend class SqlMassDataSlicerDlg;
 
 		private:
 
-		//! Pointer the a SQLite3-based database handler. 
-		/*!
-
-			\c this instance does not own the MassSpecSqlite3Handler instance.
-
-*/
-		MassSpecSqlite3Handler *mp_sqlHandler = nullptr;
-
 		//! History instance to characterize the data to be sliced off.
 		History m_history;
 
@@ -146,34 +140,59 @@ namespace msXpSmineXpert
 		int m_sliceType = SliceType::SLICE_NOT_SET;
 
 		//! Smallest value of the range to be sliced off (left range border).
-		double m_rangeStart;
+		double m_rangeStart = 0;
 
 		//! Greatest value of the range to be sliced off (right range border).
-		double m_rangeEnd;
+		double m_rangeEnd = 0;
 
 		//! Number of slices to be generated out of the initial mass data.
-		int m_sliceCount;
+		int m_sliceCount = 0;
 
 		//! Size of the slices to be generated.
-		double m_sliceSize;
+		double m_sliceSize = 0;
 
-		bool configureSpecifs(QString *errors);
 		void clearSliceSpecifications();
-		void reset();
 
 
 		public:
+		SqlMassDataSlicer();
 		SqlMassDataSlicer(const SqlMassDataSlicer &other);
-		SqlMassDataSlicer(MassSpecSqlite3Handler *sqlHandler, History history,
-				double rangeStart, double rangeEnd);
-		~SqlMassDataSlicer();
+		SqlMassDataSlicer(History history, double rangeStart, double rangeEnd);
+		virtual ~SqlMassDataSlicer();
 
+		SqlMassDataSlicer &initialize(QString fileName, double rangeStart, double rangeEnd, const History &history);
+		SqlMassDataSlicer &initialize(const SqlMassDataSlicer &other);
 		SqlMassDataSlicer &operator=(const SqlMassDataSlicer &other);
 
+		void reset();
+
+		bool configureSpecifs(QString *errors);
+
+		void setRangeStart(double value);
+		double rangeStart() const;
+		void setRangeEnd(double value);
+		double rangeEnd() const;
+		void setRange(double start, double end);
+
+		void setHistory(const History &history);
+
+		void setSliceType(int type);
+		void setSliceSize(double size);
+		void setSliceCount(int count);
+
+		void setDestDirectory(QString dir);
+		QString destDirectory() const;
+
+		void setSrcFileName(QString fileName);
+		QString srcFileName() const;
+
+		void setFormatString(QString format);
+		QString formatString() const;
+
 		QString craftSliceFileName(SliceSpecif *sliceSpecif) const;
 		QString allFileNamesAsString() const ;
 
-		bool slice();
+		QString slice(MassSpecSqlite3Handler *mp_sqlHandler);
 
 		QString asText() const;
 		QString sliceSpecifAsText(SliceSpecif *specif) const;
@@ -184,6 +203,15 @@ signals:
 		void updateSliceFileName(QString fileName);
 	};
 
+	extern QMap<int, QString> sliceTypeMap;
+
 } // namespace msXpSmineXpert
 
+Q_DECLARE_METATYPE(msXpSmineXpert::SliceSpecif);
+Q_DECLARE_METATYPE(msXpSmineXpert::SqlMassDataSlicer);
+Q_DECLARE_METATYPE(msXpSmineXpert::SqlMassDataSlicer*);
+
+extern int SliceSpecifMetaTypeId ;
+extern int sqlMassDataSlicerMetaTypeId ;
+extern int sqlMassDataSlicerPtrMetaTypeId ;
 
